@@ -36,7 +36,7 @@ static void     process_sect_line (char *line, RrnSect *sect);
 static void     process_sect_pair (RrnSect *sect, char *key, char *value);
 static int      rrn_reg_add_sect (RrnReg *reg, RrnSect *sect);
 static void     process_path (RrnReg *reg);
-static char *   process_section_path (char *owner_path, RrnSect *section);
+static void     process_section_path (char *owner_path, RrnSect *section);
 
 
 RrnReg *
@@ -57,7 +57,11 @@ rrn_reg_new ()
     reg->omf_location = NULL;
     reg->lang = NULL;
     reg->ghelp_name = NULL;
+    reg->default_section = NULL;
+    reg->hidden = FALSE;
     reg->children = NULL;
+
+    return reg;
 }
 
 RrnReg *
@@ -342,34 +346,39 @@ process_categories (char *cat_string)
 static void
 process_pair (RrnReg *reg, char *key, char *value)
 {
-    if (!strncmp (key, "Name", 4) || !strncmp (key, "name", 4)) {
-        process_field (&(reg->name), &(reg->lang), key, value);
-    } else if (!strncmp (key, "Comment", 7) || !strncmp (key, "comment", 7)) {
-        process_field (&(reg->comment), &(reg->lang), key, value);
-    } else if (!strncmp (key, "DocPath", 7) || !strncmp (key, "docpath", 7)) {
-        process_field (&(reg->uri), &(reg->lang), key, value);
-    } else if (!strcmp (key, "DocIdentifier") || !strcmp (key, "docidentifier")) {
-        reg->identifier = strdup (value);
-    } else if (!strcmp (key, "DocType") || !strcmp (key, "doctype")) {
-        reg->type = strdup (value);
-	} else if (!strcmp (key, "Categories") || !strcmp (key, "categories")) {
-		reg->categories = process_categories (value);
-	} else if (!strcmp (key, "DocWeight") || !strcmp (key, "docweight")) {
-		reg->weight = atoi (value);
-	} else if (!strcmp (key, "x-DocHeritage") || !strcmp (key, "x-docheritage")) {
-		reg->heritage = strdup (value);
-    } else if (!strcmp (key, "x-Scrollkeeper-omf-loc")) {
-      reg->omf_location = strdup(value);
-    } else if (!strcmp (key, "DocLang") || !strcmp (key, "doclang")) {
-		if (!reg->lang) {
-			reg->lang = strdup (value);
-		}
-	} else if (!strcmp (key, "Icon") || !strcmp (key, "icon")) {
-		reg->icon = strdup (value);
-    } else {
-        fprintf (stderr, "WARNING: Unknown element %s: %s\n", key, value);
+  if (!strncmp (key, "Name", 4)) {
+    process_field (&(reg->name), &(reg->lang), key, value);
+  } else if (!strncmp (key, "Comment", 7)) {
+    process_field (&(reg->comment), &(reg->lang), key, value);
+  } else if (!strncmp (key, "DocPath", 7)) {
+    process_field (&(reg->uri), &(reg->lang), key, value);
+  } else if (!strcmp (key, "DocIdentifier")) {
+    reg->identifier = strdup (value);
+  } else if (!strcmp (key, "DocType")) {
+    reg->type = strdup (value);
+  } else if (!strcmp (key, "Categories")) {
+    reg->categories = process_categories (value);
+  } else if (!strcmp (key, "DocWeight")) {
+    reg->weight = atoi (value);
+  } else if (!strcmp (key, "x-DocHeritage")) {
+    reg->heritage = strdup (value);
+  } else if (!strcmp (key, "x-Scrollkeeper-omf-loc")) {
+    reg->omf_location = strdup(value);
+  } else if (!strcmp (key, "DocLang")) {
+    if (!reg->lang) {
+      reg->lang = strdup (value);
     }
-    return;
+  } else if (!strcmp (key, "NoDisplay")) {
+    if (!strcmp (key, "true"))
+      reg->hidden = TRUE;
+  } else if (!strcmp (key, "DocDefaultSection")) {
+    reg->default_section = strdup (value);
+  } else if (!strcmp (key, "Icon")) {
+    reg->icon = strdup (value);
+  } else {
+    fprintf (stderr, "WARNING: Unknown element %s: %s\n", key, value);
+  }
+  return;
 }
 
 void
@@ -385,6 +394,8 @@ rrn_reg_free (RrnReg *reg)
   free (reg->heritage);
   free (reg->omf_location);
   free (reg->lang);
+  if (reg->default_section)
+    free (reg->default_section);
   if (reg->ghelp_name) 
     free (reg->ghelp_name);
   if (tmp) {
@@ -748,7 +759,7 @@ process_path (RrnReg *reg)
 
 }
 
-static char *
+static void
 process_section_path (char *owner_path, RrnSect *section)
 {
 	char *tmp = NULL;
